@@ -3,8 +3,12 @@ import colorGenerator as cG
 # Print some color
 red = cG.Color(rgb=(255, 0, 0))
 
+# Representation of red in HEX
+print(f"Representation of red in HEX : {red}")
+
 # Representation of red in RGB
-print(f"Representation of red in RGB : {red}")
+r, g, b = red.__repr__()
+print(f"Representation of red in RGB : {(r, g, b)}")
 
 # References
 # http://en.wikipedia.org/wiki/HLS_color_space
